| Title: | Identify differences between two XLSForm files |
|---|---|
| Description: | Package imports the "survey" sheet from two specified XLSForm files and conducts a number of comparison checks to faciliate form version control. |
| Authors: | William Oswald [aut, cre] (ORCID: <https://orcid.org/0000-0002-5287-2834>) |
| Maintainer: | William Oswald <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.0.0.9001 |
| Built: | 2026-05-17 06:03:10 UTC |
| Source: | https://github.com/williameoswald/compareXLSForms |
This function imports two XLSForm files and currently conducts a number of checks to compare each of the "survey" sheets
compare_survey(form1, form2, language)compare_survey(form1, form2, language)
form1 |
Filepath of first form as text or referring to object with location. |
form2 |
Filepath of second form as text or referring to object with location. |
language |
Specify any secondary language of the form. Form can have more than one, but this will only check one at a time. (e.g. "Francais") Entered text must match language specification in the XLSForm columns. |
List of data.frames with results of each "check" in tibbles.
## Not run: compare_forms(form1location,form2location,"Francais")## Not run: compare_forms(form1location,form2location,"Francais")
This function creates flextable formatted tables from objects stored in full_compare list output by compare_survey.
tabulate_comparison(item)tabulate_comparison(item)
item |
Number of check to tabulate. |
Flextable object.
## Not run: tabulate_comparison(1)## Not run: tabulate_comparison(1)